# React Slick Spotify Player


**Warning: This package is currently under construction and may not be stable. Please use with caution.**


## Installation

You can install the package from npm using the following command:

```bash
npm i @xartistax/react-slick-spotify-player
yarn add @xartistax/react-slick-spotify-player
pnpm add @xartistax/react-slick-spotify-player

```


## Getting Started

This package allows you to integrate a Spotify player into your React application. Follow the steps below to set up and use the player.

FYI: [Spotify API Documentation](https://developer.spotify.com/documentation/web-api).

### Step 1: Create a Spotify App

1. Go to the [Spotify Developer Dashboard](https://developer.spotify.com/dashboard).
2. Create a new app. This app will provide you with the **Client ID** and **Client Secret** needed to request an access token.

### Step 2: Request an Access Token

The access token is required for authenticating requests and contains the necessary permissions for the player to function correctly. 

### Step 3: Send a POST Request to the Token Endpoint

You can obtain the access token by sending a POST request to the token endpoint URI. Here’s how you can do it using `curl`:

```bash
curl -X POST "https://accounts.spotify.com/api/token" \
     -H "Content-Type: application/x-www-form-urlencoded" \
     -d "grant_type=client_credentials&client_id=your-client-id&client_secret=your-client-secret"
```

### Passing the Access Token to the Player Component
After obtaining the access token, you need to pass it to the Player component so that it can authenticate requests to the Spotify API. Here's how to do it:


```react
<Player accessToken={accessToken} />
```

In this code snippet, accessToken is a variable that holds the token you received from your API request. Make sure to manage this token effectively, especially considering its expiration time.


### Best Practices for Token Management

To ensure efficient and reliable access token management, consider the following best practices:

- **Automatic Token Refreshing**: Implement logic to refresh the access token automatically before it expires. This will help maintain a seamless user experience without interruptions.

- **Use Local Storage**: Store the access token and its expiration time in local storage to persist the token across page loads. This avoids the need to request a new token on every page refresh.

- **Error Handling**: Implement proper error handling to manage token fetch failures gracefully. This ensures that your application can respond appropriately to issues such as network failures or incorrect credentials.



